//package com.pokkt.plugin.common;

import com.app.pokktsdk.AdConfig;
import com.app.pokktsdk.PokktConfig;
import com.app.pokktsdk.enums.AnalyticsType;
import com.app.pokktsdk.enums.IAPStoreType;
import com.app.pokktsdk.enums.PokktIntegrationType;
import com.app.pokktsdk.model.InAppPurchaseDetail;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.Map;

public class Parsers {
    public static String getJSONStringForAdConfig(AdConfig adConfig, Map<String,String> extraValues) {
        try {
            JSONObject jsonObject = new JSONObject();

            jsonObject.put("screenName", adConfig.getScreenName());
            jsonObject.put("isRewarded", adConfig.isRewarded() ? "true" : "false");
            jsonObject.put("shouldAllowSkip", adConfig.isShouldAllowSkip() ? "true" : "false");
            jsonObject.put("backButtonDisabled", adConfig.isBackButtonDisabled() ? "true" : "false");
            jsonObject.put("shouldAllowMute", adConfig.isAllowMute() ? "true" : "false");
            jsonObject.put("shouldSkipConfirm", adConfig.getShouldSkipConfirm() ? "true" : "false");
            jsonObject.put("defaultSkipTime", adConfig.getDefaultSkipTime());
            jsonObject.put("skipConfirmMessage", adConfig.getSkipConfirmMessage());
            jsonObject.put("skipConfirmYesLabel", adConfig.getSkipConfirmYesLabel());
            jsonObject.put("skipConfirmNoLabel", adConfig.getSkipConfirmNoLabel());
            jsonObject.put("skipTimerMessage", adConfig.getSkipTimerMessage());
            jsonObject.put("incentiveMessage", adConfig.getIncentiveMessage());

            if (extraValues != null) {
                JSONObject extraValuesJSON = new JSONObject();
                for(Map.Entry<String,String> entry : extraValues.entrySet()) {
                    extraValuesJSON.put(entry.getKey(), entry.getValue());
                }
                jsonObject.put("extraValues", extraValuesJSON);
            }

            return jsonObject.toString();
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return null;
    }

    public static AdConfig getAdConfigFromJSONString(String jsonString) {
        JSONObject jsonObject;
        try {
            jsonObject = new JSONObject(jsonString);
        } catch (JSONException e) {
            e.printStackTrace();
            return null;
        }

        AdConfig adConfig = new AdConfig();

        adConfig.setScreenName(jsonObject.optString("screenName"));
        adConfig.setIsRewarded(jsonObject.optBoolean("isRewarded"));
        adConfig.setShouldAllowSkip(jsonObject.optBoolean("shouldAllowSkip"));
        adConfig.setDefaultSkipTime(jsonObject.optInt("defaultSkipTime"));
        adConfig.setSkipConfirmMessage(jsonObject.optString("skipConfirmMessage"));
        adConfig.setBackButtonDisabled(jsonObject.optBoolean("backButtonDisabled"));
        adConfig.setIsAllowMute(jsonObject.optBoolean("shouldAllowMute"));
        adConfig.setShouldSkipConfirm(jsonObject.optBoolean("shouldSkipConfirm"));
        adConfig.setSkipConfirmYesLabel(jsonObject.optString("skipConfirmYesLabel"));
        adConfig.setSkipConfirmNoLabel(jsonObject.optString("skipConfirmNoLabel"));
        adConfig.setSkipTimerMessage(jsonObject.optString("skipTimerMessage"));
        adConfig.setIncentiveMessage(jsonObject.optString("incentiveMessage"));

        return adConfig;
    }

    public static PokktConfig getPokktConfigFromJSONString(String jsonString) {
        JSONObject jsonObject;
        try {
            jsonObject = new JSONObject(jsonString);
        } catch (JSONException e) {
            e.printStackTrace();
            return null;
        }

        PokktConfig config = new PokktConfig();

        // essential
        config.setSecurityKey(jsonObject.optString("securityKey"));
        config.setApplicationId(jsonObject.optString("applicationId"));
        config.setIntegrationType(PokktIntegrationType.tryParse(jsonObject.optInt("integrationType")));
        config.setThirdPartyUserId(jsonObject.optString("thirdPartyUserId"));

        // offer wall specific
        config.setOfferWallAssetValue(jsonObject.optString("offerwallAssetValue"));
        config.setCloseOnSuccessFlag(jsonObject.optBoolean("closeOnSuccessFlag"));

        // optional
        config.setName(jsonObject.optString("name"));
        config.setAge(jsonObject.optString("age"));
        config.setSex(jsonObject.optString("sex"));
        config.setMobileNo(jsonObject.optString("mobileNo"));
        config.setEmailAddress(jsonObject.optString("emailAddress"));
        config.setLocation(jsonObject.optString("location"));
        config.setBirthday(jsonObject.optString("birthday"));
        config.setMaritalStatus(jsonObject.optString("maritalStatus"));
        config.setFacebookId(jsonObject.optString("facebookId"));
        config.setTwitterHandle(jsonObject.optString("twitterHandle"));
        config.setEducation(jsonObject.optString("education"));
        config.setNationality(jsonObject.optString("nationality"));
        config.setEmployment(jsonObject.optString("employment"));
        config.setMaturityRating(jsonObject.optString("maturityRating"));

        // analytics
        config.setGoogleAnalyticsID(jsonObject.optString("googleAnalyticsID"));
        config.setMixPanelProjectToken(jsonObject.optString("mixPanelProjectToken"));
        config.setFlurryApplicationKey(jsonObject.optString("flurryApplicationKey"));
        String analyticType = jsonObject.optString("selectedAnalyticsType").isEmpty() ? "NONE" : jsonObject.optString("selectedAnalyticsType");
        config.setSelectedAnalyticsType(AnalyticsType.valueOf(analyticType));

        return config;
    }

    public static InAppPurchaseDetail getIAPDetailsFromJSONString(String jsonString) {
        
        JSONObject jsonObject;
        try {
            jsonObject = new JSONObject(jsonString);
        } catch (JSONException e) {
            e.printStackTrace();
            return null;
        }

        InAppPurchaseDetail detail = new InAppPurchaseDetail();

        detail.setProductId(jsonObject.optString("productId"));
        detail.setPrice(jsonObject.optInt("price"));
        detail.setCurrencyCode(jsonObject.optString("currencyCode"));
        detail.setTitle(jsonObject.optString("title"));
        detail.setDescription(jsonObject.optString("description"));
        detail.setPurchaseData(jsonObject.optString("purchaseData"));
        detail.setPurchaseSignature(jsonObject.optString("purchaseSignature"));
        detail.setPurchaseStore(IAPStoreType.valueOf(jsonObject.optString("purchaseStore")));
        
        return detail;
    }
}
