//package com.pokkt.plugin.common;

import android.app.Activity;
import android.widget.Toast;

import com.app.pokktsdk.AdConfig;
import com.app.pokktsdk.PokktConfig;
import com.app.pokktsdk.PokktManager;
import com.app.pokktsdk.util.Logger;
import android.util.Log;

public class PokktManagerAdapter {

    // PRAGMA -- Run On UI Thread Helper

    interface IUIHelperFunction {
        void execute();
    }

    private static void runOnUiHelper(final IUIHelperFunction func, final Activity activity) {
        if (activity != null) {
            activity.runOnUiThread(new Runnable() {
                public void run() {
                    func.execute();
                }
            });
        } else {
            Logger.e("activity not found!");
        }
    }

    // PRAGMA --  Processor

    public static void process(String operation, String param, Activity activity) {
        switch (operation) {
            // Pokkt SDK Api
            case "setDebug":            PokktManager.setDebug(activity, Boolean.parseBoolean(param));                               break;
            case "exportLog":           PokktManagerAdapter.exportLog(activity);                                                    break;
            case "showToast":           PokktManagerAdapter.showToast(activity, param);                                             break;
            case "showLog":             Logger.d(param);                                                                            break;
            case "initPokkt":           PokktManagerAdapter.initPokkt(Parsers.getPokktConfigFromJSONString(param), activity);       break;
            case "updatePokktConfig":   PokktManagerAdapter.updatePokktConfig(Parsers.getPokktConfigFromJSONString(param));         break;

            // Session Methods
            case "startSession":        PokktManager.startSession(activity);                                                        break;
            case "endSession":          PokktManager.endSession();                                                                  break;
            case "notifyAppInstall":    PokktManager.notifyAppInstall(activity);                                                    break;
                
            case "trackIAP":            PokktManager.trackIAP(activity, Parsers.getIAPDetailsFromJSONString(param));                break;

            // Offerwall Methods
            case "getCoins":            PokktManagerAdapter.showOfferwall(Parsers.getPokktConfigFromJSONString(param), activity);   break;
            case "getPendingCoins":     PokktManagerAdapter.getPendingCoins(Parsers.getPokktConfigFromJSONString(param), activity); break;
            case "checkOfferWallCampaign": PokktManagerAdapter.checkOfferWallCampaign(Parsers.getPokktConfigFromJSONString(param), activity); break;

            // Ad Methods
            case "cacheAd":             PokktManager.cacheAd(activity, Parsers.getAdConfigFromJSONString(param));                   break;
            case "showAd":              PokktManager.showAd(activity, Parsers.getAdConfigFromJSONString(param));                    break;
            case "checkAdAvailability": PokktManager.checkAdAvailability(activity, Parsers.getAdConfigFromJSONString(param));       break;

            default: Logger.d("Unknown operation requested : " + operation + ", with param: " + param);                             break;
        }
    }

    // PRAGMA --  Pokkt Standard APIs

    private static void exportLog(final Activity activity) {
        runOnUiHelper(new IUIHelperFunction() {
            @Override
            public void execute() {
                PokktManager.exportLog(activity);
            }
        }, activity);
    }

    private static void showToast(final Activity activity, final String message) {
        runOnUiHelper(new IUIHelperFunction() {
            @Override
            public void execute() {
                Toast.makeText(activity, message, Toast.LENGTH_SHORT).show();
            }
        }, activity);
    }

    private static void initPokkt(PokktConfig config, Activity activity) {
        PokktManager.setAdDelegate(new PokktAdDelegate());
        PokktManager.initPokkt(activity, config);
    }

    private static void updatePokktConfig(PokktConfig config) {
        PokktManager.updatePokktConfig(config);
    }


    // PRAGMA -- OfferWall Methods

    private static void showOfferwall(final PokktConfig config, final Activity activity) { // TODO: set asset-value on Unity
        runOnUiHelper(new IUIHelperFunction() {
            @Override
            public void execute() {
                PokktManager.getCoins(activity, config);
            }
        }, activity);
    }

    private static void getPendingCoins(final PokktConfig config, final Activity activity) {
        runOnUiHelper(new IUIHelperFunction() {
            @Override
            public void execute() {
                PokktManager.getPendingCoins(activity, config);
            }
        }, activity);
    }

    private static void checkOfferWallCampaign(final PokktConfig config, final Activity activity) {
        runOnUiHelper(new IUIHelperFunction() {
            @Override
            public void execute() {
                PokktManager.checkCampaignAvailable(activity, config);
            }
        }, activity);
    }


    // PRAGMA -- Ad Methods

    public static float getRewardedAdVc(AdConfig adConfig) {
        return PokktManager.getRewardedAdVc(adConfig);
    }

    public static String getSDKVersion() {
        return PokktManager.getSdkVersion();
    }
}
